import 'package:equatable/equatable.dart';
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:hydrated_bloc/hydrated_bloc.dart';

import 'package:scrobbles/cubit/data_counts_by_day_cubit.dart';
import 'package:scrobbles/cubit/data_counts_by_hour_cubit.dart';
import 'package:scrobbles/cubit/data_discoveries_cubit.dart';
import 'package:scrobbles/cubit/data_heatmap_cubit.dart';
import 'package:scrobbles/cubit/data_new_artists_cubit.dart';
import 'package:scrobbles/cubit/data_new_tracks_cubit.dart';
import 'package:scrobbles/cubit/data_statistics_global_cubit.dart';
import 'package:scrobbles/cubit/data_statistics_recent_cubit.dart';
import 'package:scrobbles/cubit/data_timeline_cubit.dart';
import 'package:scrobbles/cubit/data_top_artists_cubit.dart';
import 'package:scrobbles/models/activity/activity.dart';

part 'activity_state.dart';

class ActivityCubit extends HydratedCubit<ActivityState> {
  ActivityCubit()
      : super(ActivityState(
          currentActivity: Activity.createNull(),
        ));

  void updateState(Activity activity) {
    emit(ActivityState(
      currentActivity: activity,
    ));
  }

  void refresh(BuildContext context) {
    BlocProvider.of<DataCountsByDayCubit>(context).refresh(context);
    BlocProvider.of<DataCountsByHourCubit>(context).refresh(context);
    BlocProvider.of<DataDiscoveriesCubit>(context).refresh(context);
    BlocProvider.of<DataHeatmapCubit>(context).refresh(context);
    BlocProvider.of<DataNewArtistsCubit>(context).refresh(context);
    BlocProvider.of<DataNewTracksCubit>(context).refresh(context);
    BlocProvider.of<DataStatisticsGlobalCubit>(context).refresh(context);
    BlocProvider.of<DataStatisticsRecentCubit>(context).refresh(context);
    BlocProvider.of<DataTimelineCubit>(context).refresh(context);
    BlocProvider.of<DataTopArtistsCubit>(context).refresh(context);
  }

  @override
  ActivityState? fromJson(Map<String, dynamic> json) {
    final Activity currentActivity = json['currentActivity'] as Activity;

    return ActivityState(
      currentActivity: currentActivity,
    );
  }

  @override
  Map<String, dynamic>? toJson(ActivityState state) {
    return <String, dynamic>{
      'currentActivity': state.currentActivity.toJson(),
    };
  }
}
