import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:scrobbles/cubit/activity_cubit.dart';
import 'package:unicons/unicons.dart';

import 'package:scrobbles/cubit/nav_cubit_pages.dart';
import 'package:scrobbles/config/screen.dart';
import 'package:scrobbles/cubit/nav_cubit_screens.dart';
import 'package:scrobbles/ui/helpers/app_titles.dart';

class GlobalAppBar extends StatelessWidget implements PreferredSizeWidget {
  const GlobalAppBar({super.key});

  @override
  Widget build(BuildContext context) {
    return BlocBuilder<NavCubitScreen, int>(
      builder: (BuildContext context, int screenIndex) {
        final List<Widget> menuActions = [];

        if (screenIndex == Screen.indexActivity) {
          // go to Settings page
          menuActions.add(IconButton(
            onPressed: () {
              context.read<NavCubitScreen>().goToSettingsPage();
            },
            icon: Screen.screenSettings.icon,
          ));

          // go to About page
          menuActions.add(IconButton(
            onPressed: () {
              context.read<NavCubitScreen>().goToAboutPage();
            },
            icon: Screen.screenAbout.icon,
          ));

          // refresh data
          menuActions.add(IconButton(
            onPressed: () {
              BlocProvider.of<ActivityCubit>(context).refresh(context);
            },
            icon: const Icon(UniconsSolid.refresh),
          ));
        } else {
          // back to Home page
          menuActions.add(IconButton(
            onPressed: () {
              context.read<NavCubitScreen>().goToActivityPage();
              context.read<NavCubitPage>().goToHomePage();
            },
            icon: Screen.screenActivity.icon,
          ));
        }

        return AppBar(
          title: const AppHeader(text: 'app_name'),
          actions: menuActions,
        );
      },
    );
  }

  @override
  Size get preferredSize => const Size.fromHeight(50);
}
